@@ -25,14 +25,14 @@ class ConfirmIcpIntentionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'ConfirmIcpIntention')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizIds(self):
+	def get_BizIds(self): # String
 		return self.get_query_params().get('BizIds')
 
-	def set_BizIds(self,BizIds):
-		self.add_query_param('BizIds',BizIds)
\ No newline at end of file
+	def set_BizIds(self, BizIds):  # String
+		self.add_query_param('BizIds', BizIds)
