@@ -25,14 +25,14 @@ class ConfirmTaxAmountRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'ConfirmTaxAmount')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizId(self):
+	def get_BizId(self): # String
 		return self.get_body_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_body_params('BizId', BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_body_params('BizId', BizId)
