@@ -25,38 +25,34 @@ class ListBookkeepingStatisticsesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'ListBookkeepingStatisticses')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Year(self):
+	def get_Year(self): # Integer
 		return self.get_query_params().get('Year')
 
-	def set_Year(self,Year):
-		self.add_query_param('Year',Year)
-
-	def get_ProduceBizId(self):
+	def set_Year(self, Year):  # Integer
+		self.add_query_param('Year', Year)
+	def get_ProduceBizId(self): # String
 		return self.get_query_params().get('ProduceBizId')
 
-	def set_ProduceBizId(self,ProduceBizId):
-		self.add_query_param('ProduceBizId',ProduceBizId)
-
-	def get_PageNumber(self):
+	def set_ProduceBizId(self, ProduceBizId):  # String
+		self.add_query_param('ProduceBizId', ProduceBizId)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_Month(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_Month(self): # Integer
 		return self.get_query_params().get('Month')
 
-	def set_Month(self,Month):
-		self.add_query_param('Month',Month)
-
-	def get_PageSize(self):
+	def set_Month(self, Month):  # Integer
+		self.add_query_param('Month', Month)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
