@@ -25,26 +25,24 @@ class WriteCommunicationLogRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'WriteCommunicationLog')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Note(self):
+	def get_Note(self): # String
 		return self.get_query_params().get('Note')
 
-	def set_Note(self,Note):
-		self.add_query_param('Note',Note)
-
-	def get_TargetId(self):
+	def set_Note(self, Note):  # String
+		self.add_query_param('Note', Note)
+	def get_TargetId(self): # String
 		return self.get_query_params().get('TargetId')
 
-	def set_TargetId(self,TargetId):
-		self.add_query_param('TargetId',TargetId)
-
-	def get_BizId(self):
+	def set_TargetId(self, TargetId):  # String
+		self.add_query_param('TargetId', TargetId)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
