@@ -25,62 +25,54 @@ class ListUserIntentionsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'ListUserIntentions')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Area(self):
+	def get_Area(self): # String
 		return self.get_query_params().get('Area')
 
-	def set_Area(self,Area):
-		self.add_query_param('Area',Area)
-
-	def get_BizTypes(self):
+	def set_Area(self, Area):  # String
+		self.add_query_param('Area', Area)
+	def get_BizTypes(self): # String
 		return self.get_query_params().get('BizTypes')
 
-	def set_BizTypes(self,BizTypes):
-		self.add_query_param('BizTypes',BizTypes)
-
-	def get_IntentionBizId(self):
+	def set_BizTypes(self, BizTypes):  # String
+		self.add_query_param('BizTypes', BizTypes)
+	def get_IntentionBizId(self): # String
 		return self.get_query_params().get('IntentionBizId')
 
-	def set_IntentionBizId(self,IntentionBizId):
-		self.add_query_param('IntentionBizId',IntentionBizId)
-
-	def get_PageNum(self):
+	def set_IntentionBizId(self, IntentionBizId):  # String
+		self.add_query_param('IntentionBizId', IntentionBizId)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_SortFiled(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_SortFiled(self): # String
 		return self.get_query_params().get('SortFiled')
 
-	def set_SortFiled(self,SortFiled):
-		self.add_query_param('SortFiled',SortFiled)
-
-	def get_BizType(self):
+	def set_SortFiled(self, SortFiled):  # String
+		self.add_query_param('SortFiled', SortFiled)
+	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
-
-	def get_PageSize(self):
+	def set_BizType(self, BizType):  # String
+		self.add_query_param('BizType', BizType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_SortOrder(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_SortOrder(self): # String
 		return self.get_query_params().get('SortOrder')
 
-	def set_SortOrder(self,SortOrder):
-		self.add_query_param('SortOrder',SortOrder)
-
-	def get_Status(self):
+	def set_SortOrder(self, SortOrder):  # String
+		self.add_query_param('SortOrder', SortOrder)
+	def get_Status(self): # Integer
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # Integer
+		self.add_query_param('Status', Status)
