@@ -25,32 +25,29 @@ class SubmitSolutionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-03-06', 'SubmitSolution')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BizType(self):
+	def get_BizType(self): # String
 		return self.get_query_params().get('BizType')
 
-	def set_BizType(self,BizType):
-		self.add_query_param('BizType',BizType)
-
-	def get_Solution(self):
+	def set_BizType(self, BizType):  # String
+		self.add_query_param('BizType', BizType)
+	def get_Solution(self): # String
 		return self.get_query_params().get('Solution')
 
-	def set_Solution(self,Solution):
-		self.add_query_param('Solution',Solution)
-
-	def get_IntentionBizId(self):
+	def set_Solution(self, Solution):  # String
+		self.add_query_param('Solution', Solution)
+	def get_IntentionBizId(self): # String
 		return self.get_query_params().get('IntentionBizId')
 
-	def set_IntentionBizId(self,IntentionBizId):
-		self.add_query_param('IntentionBizId',IntentionBizId)
-
-	def get_UserId(self):
+	def set_IntentionBizId(self, IntentionBizId):  # String
+		self.add_query_param('IntentionBizId', IntentionBizId)
+	def get_UserId(self): # String
 		return self.get_query_params().get('UserId')
 
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
\ No newline at end of file
+	def set_UserId(self, UserId):  # String
+		self.add_query_param('UserId', UserId)
