@@ -25,26 +25,24 @@ class CheckCopyPayrollRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'CheckCopyPayroll')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Period(self):
+	def get_Period(self): # String
 		return self.get_query_params().get('Period')
 
-	def set_Period(self,Period):
-		self.add_query_param('Period',Period)
-
-	def get_UpdateEmployeeFlag(self):
+	def set_Period(self, Period):  # String
+		self.add_query_param('Period', Period)
+	def get_UpdateEmployeeFlag(self): # Boolean
 		return self.get_query_params().get('UpdateEmployeeFlag')
 
-	def set_UpdateEmployeeFlag(self,UpdateEmployeeFlag):
-		self.add_query_param('UpdateEmployeeFlag',UpdateEmployeeFlag)
-
-	def get_BizId(self):
+	def set_UpdateEmployeeFlag(self, UpdateEmployeeFlag):  # Boolean
+		self.add_query_param('UpdateEmployeeFlag', UpdateEmployeeFlag)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
