@@ -25,92 +25,79 @@ class ConvertInvoiceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'ConvertInvoice')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_IsFee(self):
+	def get_IsFee(self): # Boolean
 		return self.get_query_params().get('IsFee')
 
-	def set_IsFee(self,IsFee):
-		self.add_query_param('IsFee',IsFee)
-
-	def get_ShellMethod(self):
+	def set_IsFee(self, IsFee):  # Boolean
+		self.add_query_param('IsFee', IsFee)
+	def get_ShellMethod(self): # String
 		return self.get_query_params().get('ShellMethod')
 
-	def set_ShellMethod(self,ShellMethod):
-		self.add_query_param('ShellMethod',ShellMethod)
-
-	def get_Kind(self):
+	def set_ShellMethod(self, ShellMethod):  # String
+		self.add_query_param('ShellMethod', ShellMethod)
+	def get_Kind(self): # String
 		return self.get_query_params().get('Kind')
 
-	def set_Kind(self,Kind):
-		self.add_query_param('Kind',Kind)
-
-	def get_Use(self):
+	def set_Kind(self, Kind):  # String
+		self.add_query_param('Kind', Kind)
+	def get_Use(self): # String
 		return self.get_query_params().get('Use')
 
-	def set_Use(self,Use):
-		self.add_query_param('Use',Use)
-
-	def get_ThirdKey(self):
+	def set_Use(self, Use):  # String
+		self.add_query_param('Use', Use)
+	def get_ThirdKey(self): # String
 		return self.get_query_params().get('ThirdKey')
 
-	def set_ThirdKey(self,ThirdKey):
-		self.add_query_param('ThirdKey',ThirdKey)
-
-	def get_Payer(self):
+	def set_ThirdKey(self, ThirdKey):  # String
+		self.add_query_param('ThirdKey', ThirdKey)
+	def get_Payer(self): # String
 		return self.get_query_params().get('Payer')
 
-	def set_Payer(self,Payer):
-		self.add_query_param('Payer',Payer)
-
-	def get_SecondKey(self):
+	def set_Payer(self, Payer):  # String
+		self.add_query_param('Payer', Payer)
+	def get_SecondKey(self): # String
 		return self.get_query_params().get('SecondKey')
 
-	def set_SecondKey(self,SecondKey):
-		self.add_query_param('SecondKey',SecondKey)
-
-	def get_PayMethod(self):
+	def set_SecondKey(self, SecondKey):  # String
+		self.add_query_param('SecondKey', SecondKey)
+	def get_PayMethod(self): # String
 		return self.get_query_params().get('PayMethod')
 
-	def set_PayMethod(self,PayMethod):
-		self.add_query_param('PayMethod',PayMethod)
-
-	def get_BuyMethod(self):
+	def set_PayMethod(self, PayMethod):  # String
+		self.add_query_param('PayMethod', PayMethod)
+	def get_BuyMethod(self): # String
 		return self.get_query_params().get('BuyMethod')
 
-	def set_BuyMethod(self,BuyMethod):
-		self.add_query_param('BuyMethod',BuyMethod)
-
-	def get_FixedAssetType(self):
+	def set_BuyMethod(self, BuyMethod):  # String
+		self.add_query_param('BuyMethod', BuyMethod)
+	def get_FixedAssetType(self): # String
 		return self.get_query_params().get('FixedAssetType')
 
-	def set_FixedAssetType(self,FixedAssetType):
-		self.add_query_param('FixedAssetType',FixedAssetType)
-
-	def get_FirstKey(self):
+	def set_FixedAssetType(self, FixedAssetType):  # String
+		self.add_query_param('FixedAssetType', FixedAssetType)
+	def get_FirstKey(self): # String
 		return self.get_query_params().get('FirstKey')
 
-	def set_FirstKey(self,FirstKey):
-		self.add_query_param('FirstKey',FirstKey)
-
-	def get_BizId(self):
+	def set_FirstKey(self, FirstKey):  # String
+		self.add_query_param('FirstKey', FirstKey)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
-
-	def get_Id(self):
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
+	def get_Id(self): # Long
 		return self.get_query_params().get('Id')
 
-	def set_Id(self,Id):
-		self.add_query_param('Id',Id)
-
-	def get_BuyTarget(self):
+	def set_Id(self, Id):  # Long
+		self.add_query_param('Id', Id)
+	def get_BuyTarget(self): # String
 		return self.get_query_params().get('BuyTarget')
 
-	def set_BuyTarget(self,BuyTarget):
-		self.add_query_param('BuyTarget',BuyTarget)
\ No newline at end of file
+	def set_BuyTarget(self, BuyTarget):  # String
+		self.add_query_param('BuyTarget', BuyTarget)
