@@ -25,26 +25,24 @@ class GetBalanceSheetInfoRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'GetBalanceSheetInfo')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Period(self):
+	def get_Period(self): # String
 		return self.get_query_params().get('Period')
 
-	def set_Period(self,Period):
-		self.add_query_param('Period',Period)
-
-	def get_IsReclassification(self):
+	def set_Period(self, Period):  # String
+		self.add_query_param('Period', Period)
+	def get_IsReclassification(self): # Boolean
 		return self.get_query_params().get('IsReclassification')
 
-	def set_IsReclassification(self,IsReclassification):
-		self.add_query_param('IsReclassification',IsReclassification)
-
-	def get_BizId(self):
+	def set_IsReclassification(self, IsReclassification):  # Boolean
+		self.add_query_param('IsReclassification', IsReclassification)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
