@@ -25,20 +25,19 @@ class GetOssStsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'GetOssSts')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OssKey(self):
+	def get_OssKey(self): # String
 		return self.get_query_params().get('OssKey')
 
-	def set_OssKey(self,OssKey):
-		self.add_query_param('OssKey',OssKey)
-
-	def get_BizId(self):
+	def set_OssKey(self, OssKey):  # String
+		self.add_query_param('OssKey', OssKey)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
