@@ -25,20 +25,19 @@ class SaveOpeningBalanceStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'SaveOpeningBalanceStatus')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OpeningBalanceStatus(self):
+	def get_OpeningBalanceStatus(self): # String
 		return self.get_query_params().get('OpeningBalanceStatus')
 
-	def set_OpeningBalanceStatus(self,OpeningBalanceStatus):
-		self.add_query_param('OpeningBalanceStatus',OpeningBalanceStatus)
-
-	def get_BizId(self):
+	def set_OpeningBalanceStatus(self, OpeningBalanceStatus):  # String
+		self.add_query_param('OpeningBalanceStatus', OpeningBalanceStatus)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
