@@ -25,20 +25,19 @@ class UpdateTaxInfoRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'UpdateTaxInfo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UpdatedTaxInfo(self):
+	def get_UpdatedTaxInfo(self): # String
 		return self.get_query_params().get('UpdatedTaxInfo')
 
-	def set_UpdatedTaxInfo(self,UpdatedTaxInfo):
-		self.add_query_param('UpdatedTaxInfo',UpdatedTaxInfo)
-
-	def get_BizId(self):
+	def set_UpdatedTaxInfo(self, UpdatedTaxInfo):  # String
+		self.add_query_param('UpdatedTaxInfo', UpdatedTaxInfo)
+	def get_BizId(self): # String
 		return self.get_query_params().get('BizId')
 
-	def set_BizId(self,BizId):
-		self.add_query_param('BizId',BizId)
\ No newline at end of file
+	def set_BizId(self, BizId):  # String
+		self.add_query_param('BizId', BizId)
